@@ -22,9 +22,9 @@
 #define MAX_ITER 1000000
 
 static int status0;
-static int lambda0;
+static double lambda0;
 static double *x;
-static double pi = 3.14159265359;
+
 
 int ratio_test0(
 	double *dy, 
@@ -88,11 +88,6 @@ void fastlp(double *obj, double *mat, double *rhs, int *m0 , int *n0, double *op
 	b[i]=rhs[i];
     }
 
-    for (i=0;i<m;i++){
-       for(j=0;j<n;j++){
-	
-       }	
-    }
 
 
     k=0;
@@ -162,7 +157,7 @@ void solver20(
     int     col_out;	/* leaving column; index in 'basics' */
     int     iter = 0;	/* number of iterations */
     int     i,j,k,v=0;
-    double  s, t, sbar, tbar, mu=HUGE_VAL, primal_obj;
+    double  s, t, sbar, tbar, mu=HUGE_VAL;
     double  *vec;
     int    *ivec;
     int     nvec;
@@ -426,16 +421,11 @@ void solver20(
 
       from_scratch = refactor( m, ka, ia, a, basics, col_out, v );
 
-      if (from_scratch) {
-          primal_obj = sdotprod(c,x_B,basics,m);
 
-      }
-
-      primal_obj = sdotprod(c,x_B,basics,m);
 
   } 
 
-      //primal_obj = sdotprod(c,x_B,basics,m);
+    
 
       for (i=0; i<m; i++) {
 	  x[basics[i]] = x_B[i];
